@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from cator.base import Table
+from ..base import Table
 
 
 class MysqlTable(Table):
@@ -8,5 +8,5 @@ class MysqlTable(Table):
     def columns(self):
         sql = 'SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = :table_name'
         params = {'table_name': self.table_name}
-        rows = self.database.select(operation=sql, params=params)
+        rows = self.database.select(sql=sql, params=params)
         return [row['COLUMN_NAME'] for row in rows]
